Learn R Programming

IBCF.MTME (version 1.6-0)

IBCF: IBCF

Description

Item Based Collaborative Filtering for multi-trait and multi-environment data.

Usage

IBCF(object, dec = 4)

Arguments

object

list CrossValidation object, is obtained from CV.RandomPartition function.

dec

integer Number of decimals to print in the results.

Value

A list with the next components

NPartitions

integer Number of partitions used for testing data

predictions_Summary

data.frame A data.frame with the results of the test

Predictions

list A list with the predicted results for each partition

Examples

Run this code
# NOT RUN {
 
# }
# NOT RUN {
  library(IBCF.MTME)
  data('Wheat_IBCF')

  CV <- CV.RandomPart(Wheat_IBCF)
  IBCF(CV)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab