Learn R Programming

IBCF.MTME (version 1.6-0)

IBCF.Years: IBCF.Years

Description

Item Based Collaborative Filtering for Years data

Usage

IBCF.Years(DataSet, colYears = 1, colID = 2, Years.testing = "",
  Traits.testing = "", dec = 4)

Arguments

DataSet

data.frame A data set in Matrix Form.

colYears

string or integer A name or the position of the 'Years' column just in case that is not the first column.

colID

string or integer A name or the position of the 'ID' column, just in case that is not the second column.

Years.testing

vector A vector with the names of the years to use in test.

Traits.testing

vector A vector with the names of the traits to use in test.

dec

integer Number of decimals to print in the results.

Value

A list with the next components

Year.testing

vector a vector with the Years used for the testing data

Traits.testing

vector a vector with the Traits used for the testing data

Data_Obs_Pred

data.frame Contains the values observed and predicted (the predicted values has '.1' after the name)

predictions_Summary

data.frame Contains the summary of the correlation of the predictions and the MAAPE

Examples

Run this code
# NOT RUN {
  library(IBCF.MTME)
  data('Year_IBCF')
  DataSet <- getMatrixForm(Year_IBCF, onlyTrait = TRUE)
  IBCF.Years(DataSet , Years.testing = c('2015', '2016'), Traits.testing = c('T5', 'T6'))

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab