powered by
Item Based Collaborative Filtering for multi-trait and multi-environment data.
IBCF(object, dec = 4)
list CrossValidation object, is obtained from CV.RandomPartition function.
list
integer Number of decimals to print in the results.
integer
A list with the next components
integer Number of partitions used for testing data
data.frame A data.frame with the results of the test
data.frame
list A list with the predicted results for each partition
# NOT RUN { # } # NOT RUN { library(IBCF.MTME) data('Wheat_IBCF') CV <- CV.RandomPart(Wheat_IBCF) IBCF(CV) # } # NOT RUN { # }
Run the code above in your browser using DataLab